@@ -139,6 +139,7 @@ class ApplicationCode(
     '''(experimental) Code configuration providing the location to a Flink application JAR file.
 
     :stability: experimental
+    :exampleMetadata: lit=test/integ.application.lit.ts ! show
 
     Example::
 
@@ -275,6 +276,7 @@ class ApplicationCodeConfig:
         :param bucket: (experimental) S3 Bucket that stores the Flink application code.
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
 
         Example::
 
@@ -520,6 +522,7 @@ class ApplicationProps:
         :param snapshots_enabled: (experimental) Determines if Flink snapshots are enabled. Default: true
 
         :stability: experimental
+        :exampleMetadata: lit=test/integ.application.lit.ts ! show
 
         Example::
 
@@ -1027,6 +1030,7 @@ class Runtime(
     '''(experimental) Available Flink runtimes for Kinesis Analytics.
 
     :stability: experimental
+    :exampleMetadata: lit=test/integ.application.lit.ts ! show
 
     Example::
 
@@ -1111,6 +1115,7 @@ class Application(
     '''(experimental) The L2 construct for Flink Kinesis Data Applications.
 
     :stability: experimental
+    :exampleMetadata: lit=test/integ.application.lit.ts ! show
     :resource: AWS::KinesisAnalyticsV2::Application
 
     Example::
